@@ -65,7 +65,6 @@ public:
 	bool checkWord (const char *word, size_t len);
 	char **suggestWord (const char* const word, size_t len, size_t *out_n_suggs);
 	const char *getWordchars ();
-	bool apostropheIsWordChar;
 
 	bool requestDictionary (const char * szLang);
 
@@ -84,7 +83,7 @@ g_iconv_is_valid(GIConv i)
 }
 
 HunspellChecker::HunspellChecker()
-: apostropheIsWordChar(false), m_translate_in(nullptr), m_translate_out(nullptr), hunspell(nullptr)
+: m_translate_in(nullptr), m_translate_out(nullptr), hunspell(nullptr)
 {
 }
 
@@ -115,7 +114,7 @@ HunspellChecker::checkWord(const char *utf8Word, size_t len)
 	if (static_cast<size_t>(-1) == result)
 		return false;
 	*out = '\0';
-	if (hunspell->spell(std::string(word8)))
+	if (hunspell->spell(word8))
 		return true;
 	else
 		return false;
@@ -142,23 +141,29 @@ HunspellChecker::suggestWord(const char* const utf8Word, size_t len, size_t *nsu
 		return nullptr;
 
 	*out = '\0';
-	std::vector<std::string> sugMS = hunspell->suggest(word8);
-	*nsug = sugMS.size();
+	char **sugMS;
+	*nsug = hunspell->suggest(&sugMS, word8);
 	if (*nsug > 0) {
 		char **sug = g_new0 (char *, *nsug + 1);
 		for (size_t i=0; i<*nsug; i++) {
-			in = const_cast<char *>(sugMS[i].c_str());
+			in = sugMS[i];
 			len_in = strlen(in);
 			len_out = MAXWORDLEN;
 			char *word = g_new0(char, len_out + 1);
 			out = word;
 			if (static_cast<size_t>(-1) == g_iconv(m_translate_out, &in, &len_in, &out, &len_out)) {
+				for (size_t j = i; j < *nsug; j++)
+					free(sugMS[j]);
+				free(sugMS);
+
 				*nsug = i;
-				break;
+				return sug;
 			}
-			*out = '\0';
+			*(out) = 0;
 			sug[i] = word;
+			free(sugMS[i]);
 		}
+		free(sugMS);
 		return sug;
 	}
 	else
@@ -177,32 +182,24 @@ s_buildDictionaryDirs (std::vector<std::string> & dirs)
 	dirs.clear ();
 
 	char * config_dir = enchant_get_user_config_dir ();
-	gchar * tmp = g_build_filename (config_dir, "hunspell", nullptr);
-	dirs.push_back (tmp);
+	dirs.push_back (g_build_filename (config_dir, "hunspell", nullptr));
 	free (config_dir);
-	g_free(tmp);
 
 	for (const gchar* const * iter = g_get_system_data_dirs (); *iter; iter++)
 		{
-			tmp = g_build_filename (*iter, "hunspell", nullptr);
-			dirs.push_back (tmp);
-			g_free(tmp);
+			dirs.push_back (g_build_filename (*iter, "hunspell", nullptr));
 		}
 
 	/* Dynamically locate library and search for modules relative to it. */
 	char * enchant_prefix = enchant_get_prefix_dir();
 	if(enchant_prefix)
 		{
-			tmp = g_build_filename(enchant_prefix, "share", "enchant", "hunspell", nullptr);
-			dirs.push_back (tmp);
-			free(enchant_prefix);
-			g_free(tmp);
+			dirs.push_back (g_build_filename(enchant_prefix, "share", "enchant", "hunspell", nullptr));
+			g_free(enchant_prefix);
 		}
 
 #ifdef ENCHANT_HUNSPELL_DICT_DIR
-	config_dir = enchant_relocate (ENCHANT_HUNSPELL_DICT_DIR);
-	dirs.push_back (config_dir);
-	free(config_dir);
+	dirs.push_back (enchant_relocate (ENCHANT_HUNSPELL_DICT_DIR));
 #endif
 }
 
@@ -289,7 +286,6 @@ hunspell_request_dictionary (const char * tag)
 						g_dir_close (dir);
 						return dict;
 					}
-					g_free(dict);
 				}
 			}
 
@@ -310,8 +306,6 @@ HunspellChecker::requestDictionary(const char *szLang)
 	std::string aff(s_correspondingAffFile(dic));
 	if (s_fileExists(aff))
 	{
-		if (hunspell)
-			delete hunspell;
 		hunspell = new Hunspell(aff.c_str(), dic);
 	}
 	free(dic);
@@ -323,10 +317,6 @@ HunspellChecker::requestDictionary(const char *szLang)
 	m_translate_in = g_iconv_open(enc, "UTF-8");
 	m_translate_out = g_iconv_open("UTF-8", enc);
 
-	const char *word_chars = hunspell->get_wordchars();
-	apostropheIsWordChar = g_utf8_strchr(word_chars, -1, g_utf8_get_char("'")) ||
-		g_utf8_strchr(word_chars, -1, g_utf8_get_char("’"));
-
 	return true;
 }
 
@@ -363,12 +353,8 @@ hunspell_dict_get_extra_word_characters (EnchantDict *me)
 static int
 hunspell_dict_is_word_character (EnchantDict *me, uint32_t uc, size_t n)
 {
+	(void)n;
 	HunspellChecker * checker = static_cast<HunspellChecker *>(me->user_data);
-	/* Accept quote marks anywhere except at the end of a word, as per
-	   hunspell's textparser.cxx/TextParser::next_token */
-	if ((uc == g_utf8_get_char("'") || uc == g_utf8_get_char("’")) && checker->apostropheIsWordChar) {
-		return n < 2;
-	}
 	return g_unichar_isalpha(uc) || g_utf8_strchr(checker->getWordchars(), -1, uc);
 }
 
